@@ -1,6 +1,6 @@
 "Collection of generic-purpose and stand-alone functions"
 
-__version__ = "0.0.8"
+__version__ = "0.3.0"
 
 from .factors import *
 from .logical import *
@@ -8,4 +8,5 @@ from .class_utils import *
 from .extensions import *
 from .indexes import *
 from .functools import *
-from .gammas import *
+from .numpy import *
+from .io import *
